@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2014-09-03'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2014-09-05'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -15,6 +15,8 @@ extends 'Perinci::CmdLine::Base';
 # error message if base class has errors.
 #use parent 'Perinci::CmdLine::Base';
 
+my $formats = [qw/text text-simple text-pretty json json-pretty/];
+
 sub BUILD {
     my ($self, $args) = @_;
 
@@ -55,8 +57,7 @@ sub BUILD {
             format => {
                 getopt  => 'format=s',
                 summary => 'Set output format',
-                schema => ['str*' => in => [qw/text text-simple text-pretty
-                                               json json-pretty/]],
+                schema => ['str*' => in => $formats],
                 handler => sub {
                     my ($go, $val, $r) = @_;
                     $r->{format} = $val;
@@ -130,7 +131,7 @@ sub BUILD {
         $self->{common_opts} = $co;
     }
 
-    $self->{formats} //= [qw/text text-simple text-pretty json/];
+    $self->{formats} //= $formats;
 
     $self->{per_arg_json} //= 1;
 }
@@ -226,7 +227,7 @@ sub hook_format_result {
         JSON->new->allow_nonref;
     };
     if ($format eq 'json') {
-        return $json->encode($res);
+        return $json->encode($res) . "\n";
     } else {
         return $json->pretty->encode($res);
     }
@@ -471,7 +472,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.27 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-09-03.
+This document describes version 0.28 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2014-09-05.
 
 =head1 SYNOPSIS
 
